CupertinoBottomBarTheme class

Inheritance
Annotations

Constructors

CupertinoBottomBarTheme({Color? bgColor, double? height, Color? selectedItemColor, Color? unselectedItemColor, BottomNavigationBarType? type, Border? border, double iconSize = 24})

Properties

bgColor → Color?
finalinherited
border → Border?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
iconSize → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemColor → Color?
final
type → BottomNavigationBarType?
final
unselectedItemColor → Color?
final

Methods

copyWith({Color? selectedItemColor, Color? unselectedItemColor, Color? bgColor, BottomNavigationBarType? type, double? iconSize, double? height, Border? border}) → CupertinoBottomBarTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited