Material2BottomBarTheme class

Inheritance
Annotations

Constructors

Material2BottomBarTheme({Color? bgColor, double? height, Color? selectedItemColor, Color? unselectedItemColor, BottomNavigationBarType? type, IconThemeData? iconThemeData, double? elevation, double selectedFontSize = 14.0, double unselectedFontSize = 12.0, double iconSize = 24})

Properties

bgColor → Color?
finalinherited
elevation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
iconSize → double
final
iconThemeData → IconThemeData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedFontSize → double
final
selectedItemColor → Color?
final
type → BottomNavigationBarType?
final
unselectedFontSize → double
final
unselectedItemColor → Color?
final

Methods

copyWith({Color? selectedItemColor, Color? unselectedItemColor, Color? bgColor, BottomNavigationBarType? type, IconThemeData? iconThemeData, double? elevation, double? selectedFontSize, double? unselectedFontSize, double? iconSize, double? height}) → Material2BottomBarTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited