Material3BottomBarTheme class

Inheritance
Annotations

Constructors

Material3BottomBarTheme({Color? bgColor, double? height, Duration? animationDuration, NavigationDestinationLabelBehavior? labelBehavior, double? elevation})

Properties

animationDuration → Duration?
final
bgColor → Color?
finalinherited
elevation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
labelBehavior → NavigationDestinationLabelBehavior?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Duration? animationDuration, NavigationDestinationLabelBehavior? labelBehavior, double? elevation, Color? bgColor, double? height}) → Material3BottomBarTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited