ScaffoldOptions class

Constructors

ScaffoldOptions({Key? key, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, List<Widget>? persistentFooterButtons, Widget? drawer, DrawerCallback? onDrawerChanged, Widget? endDrawer, DrawerCallback? onEndDrawerChanged, Widget? bottomSheet, Color? backgroundColor, bool? resizeToAvoidBottomInset, bool? primary, DragStartBehavior? drawerDragStartBehavior, bool? extendBody, Color? drawerScrimColor, double? drawerEdgeDragWidth, bool? drawerEnableOpenDragGesture, bool? endDrawerEnableOpenDragGesture, String? restorationId, bool? extendBodyBehindAppBar})

Properties

backgroundColor → Color?
final
bottomSheet → Widget?
final
drawer → Widget?
final
drawerDragStartBehavior → DragStartBehavior?
final
drawerEdgeDragWidth → double?
final
drawerEnableOpenDragGesture → bool?
final
drawerScrimColor → Color?
final
endDrawer → Widget?
final
endDrawerEnableOpenDragGesture → bool?
final
extendBody → bool?
final
extendBodyBehindAppBar → bool?
final
floatingActionButton → Widget?
final
floatingActionButtonAnimator → FloatingActionButtonAnimator?
final
floatingActionButtonLocation → FloatingActionButtonLocation?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
final
onDrawerChanged → DrawerCallback?
final
onEndDrawerChanged → DrawerCallback?
final
persistentFooterButtons → List<Widget>?
final
primary → bool?
final
resizeToAvoidBottomInset → bool?
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited