BartBottomBar class

Inheritance

Constructors

BartBottomBar.adaptive({Material3BottomBarTheme? materialBottomBarTheme, CupertinoBottomBarTheme? cupertinoBottomBarTheme, bool enableHapticFeedback = true, int index = 0})
factory
BartBottomBar.cupertino({Color? bgColor, Color? selectedItemColor, Color? unselectedItemColor, BottomNavigationBarType? type, double iconSize = 24, double? height, Border? border, bool enableHapticFeedback = true, int index = 0})
factory
BartBottomBar.custom({required BartBottomBarFactory bottomBarFactory, int index = 0})
factory
BartBottomBar.material({bool enableHapticFeedback = true, int index = 0, Color? bgColor, Color? selectedItemColor, Color? unselectedItemColor, double? height, BottomNavigationBarType? type, IconThemeData? iconThemeData, double selectedFontSize = 14.0, double unselectedFontSize = 12.0, double iconSize = 24, double? elevation})
factory
BartBottomBar.material3({Duration? animationDuration, NavigationDestinationLabelBehavior? labelBehavior, double? elevation, Color? bgColor, double? height, bool enableHapticFeedback = true, int index = 0})
factory

Properties

bottomBarCustom → BartBottomBarFactory?
final
bottomBarTheme → CommonBottomBarTheme?
final
currentIndex → int
final
enableHapticFeedback → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → BartBottomBarStyle
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → BartBottomBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited